searchData={"items":[{"type":"module","title":"Supabase.Functions","doc":"This module provides integration with the Supabase Edge Functions API, enabling developers\nto invoke their serverless functions.","ref":"Supabase.Functions.html"},{"type":"module","title":"Usage - Supabase.Functions","doc":"iex> client = Supabase.init_client!(\"SUPABASE_URL\", \"SUPABASE_KEY\")\n    iex> Supabase.Functions.invoke(client, \"function_name\", %{})","ref":"Supabase.Functions.html#module-usage"},{"type":"function","title":"Supabase.Functions.invoke/3","doc":"Invokes a function\n\nInvoke a Supabase Edge Function.\n\n- When you pass in a body to your function, we automatically attach the `Content-Type` header automatically. If it doesn't match any of these types we assume the payload is json, serialize it and attach the `Content-Type` header as `application/json`. You can override this behavior by passing in a `Content-Type` header of your own.\n- Responses are automatically parsed as json depending on the Content-Type header sent by your function. Responses are parsed as text by default.","ref":"Supabase.Functions.html#invoke/3"},{"type":"type","title":"Supabase.Functions.on_response/0","doc":"","ref":"Supabase.Functions.html#t:on_response/0"},{"type":"type","title":"Supabase.Functions.opt/0","doc":"Available options for invoking a function:\n\n- `body`: The body of the request.\n- `headers`: The additional custom headers of the request.\n- `method`: The HTTP method of the request.\n- `region`: The Region to invoke the function in.\n- `on_response`: The custom response handler for response streaming.","ref":"Supabase.Functions.html#t:opt/0"},{"type":"type","title":"Supabase.Functions.opts/0","doc":"","ref":"Supabase.Functions.html#t:opts/0"},{"type":"type","title":"Supabase.Functions.region/0","doc":"","ref":"Supabase.Functions.html#t:region/0"},{"type":"extras","title":"Supabase Functions","doc":"# Supabase Functions\n\n[Edge Functions](https://supabase.com/docs/guides/functions) client implementation for the [Supabase Potion](https://github.com/supabase-community/supabase-ex) SDK in Elixir","ref":"readme.html"},{"type":"extras","title":"Installation - Supabase Functions","doc":"```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.6\"},\n    {:supabase_functions, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Supabase Functions","doc":"Given a simple Edge Function that simply echos a raw string:\n\n```ts\n// simple-text/index.ts\nDeno.serve(async (req) => {\n  return new Response(\"Hello from Deno!\", {\n    headers: { \"Content-Type\": \"text/plain\" }\n  });\n});\n```\n\nFrom your Elixir server, after having started your `Supabase.Client` yo ucan inke this function as\n\n```elixir\nclient = Supabase.init_client!(\"SUPABASE_URl\", \"SUPABASE_KEY\")\n\nSupabase.Functions.invoke(client, \"simple-text\")\n# {:ok, %Supabase.Response{status: 200, body: \"Hello from Deno!\"}}\n```\n\nIt also work with data streaming, given an Edge Function\n\n```ts\n// stream-data/index.ts\nDeno.serve(async (req) => {\n  const stream = new ReadableStream({\n    start(controller) {\n      let count = 0;\n      const interval = setInterval(() => {\n        if (count >= 5) {\n          clearInterval(interval);\n          controller.close();\n          return;\n        }\n        const message = `Event ${count}\\n`;\n        controller.enqueue(new TextEncoder().encode(message));\n        count++;\n      }, 1000);\n    }\n  });\n\n  return new Response(stream, {\n    headers: {\n      \"Content-Type\": \"text/event-stream\",\n      \"Cache-Control\": \"no-cache\",\n      \"Connection\": \"keep-alive\"\n    }\n  });\n});\n```\n\nThe you could invoke it as\n\n```elixir\nclient = Supabase.init_client!(\"SUPABASE_URl\", \"SUPABASE_KEY\")\n\n# you can control the response streaming handling too (optional)\non_response = fn {status, headers, body} ->\n  require Logger\n\n  Logger.info(\"received response with #{status} status\")\n  Logger.info(\"received #{inspect(headers, pretty: true)} headers\")\n\n  file = File.stream!(\"output.txt\", [:write, :utf8])\n\n  body\n  |> Stream.into(file)\n  |> Stream.run()\nend\n\nSupabase.Functions.invoke(client, \"stream-data\", on_response: on_response)\n# :ok\n```","ref":"readme.html#usage"},{"type":"extras","title":"CHANGELOG","doc":"","ref":"changelog.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}